#!D:\bld\gdal-split_1626818978837\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.3.1','gdal2xyz.py'
__requires__ = 'GDAL==3.3.1'
__import__('pkg_resources').run_script('GDAL==3.3.1', 'gdal2xyz.py')
